==> gnome-latex-3.39.1.tar.xz: gnome-latex-3.39.1/docs/more-information.md <==
gnome-latex - more information
==============================

About versions
--------------

gnome-latex follows the even/odd minor version scheme.

For example the `3.37.x` versions are unstable (development versions), and the
`3.38.x` versions are stable.

Dependencies
------------

- GLib
- GTK 3
- GtkSourceView 4
- [Tepl](https://gitlab.gnome.org/swilmet/tepl) >= 5.99.1
- gspell
- [gee-0.8](https://wiki.gnome.org/Projects/Libgee)
- gsettings-desktop-schemas
- dconf (optional, recommended on Linux, can be disabled with
  `--disable-dconf-migration`)
- Latexmk >= 4.31 (optional, but strongly recommended)

And for building the sources:
- Vala >= 0.46 (may be optional)
- yelp-tools

If you are installing gnome-latex from a tarball, you don't have to install
Vala because the C code is already generated.

Installation
------------

Simple install procedure from a tarball:

```
$ ./configure
$ make
[ Become root if necessary ]
$ make install
```

See the file 'INSTALL' for more detailed information.

From the Git repository, the 'configure' script and the 'INSTALL' file are not
yet generated, so you need to run 'autogen.sh' instead, which takes the same
arguments as 'configure'.

Some links
----------

- [Project home page](https://gitlab.gnome.org/swilmet/gnome-latex)
- [gnome-latex-extra](https://gitlab.gnome.org/swilmet/gnome-latex-extra) git
  repository
- [Tarballs](https://download.gnome.org/sources/gnome-latex/)
- [Old latexila tarballs](https://download.gnome.org/sources/latexila/)
- [Old mailing list](https://mail.gnome.org/mailman/listinfo/latexila-list)

Development and maintenance
---------------------------

The project is in low-maintenance state.

==> gnome-latex-3.40.0.tar.xz: gnome-latex-3.40.0/docs/more-information.md <==
gnome-latex - more information
==============================

About versions
--------------

gnome-latex follows the even/odd minor version scheme.

For example the `3.37.x` versions are unstable (development versions), and the
`3.38.x` versions are stable.

Dependencies
------------

- GLib
- GTK 3
- GtkSourceView 4
- [Tepl](https://gitlab.gnome.org/swilmet/tepl) >= 5.99.1
- gspell
- [gee-0.8](https://wiki.gnome.org/Projects/Libgee)
- gsettings-desktop-schemas
- dconf (optional, recommended on Linux, can be disabled with
  `--disable-dconf-migration`)
- Latexmk >= 4.31 (optional, but strongly recommended)

And for building the sources:
- Vala >= 0.46 (may be optional)
- yelp-tools

If you are installing gnome-latex from a tarball, you don't have to install
Vala because the C code is already generated.

Installation
------------

### Packages

See the [packages.md](packages.md) page.

### Simple install procedure from a tarball

```
$ ./configure
$ make
[ Become root if necessary ]
$ make install
```

See the file 'INSTALL' for more detailed information.

From the Git repository, the 'configure' script and the 'INSTALL' file are not
yet generated, so you need to run 'autogen.sh' instead, which takes the same
arguments as 'configure'.

Some links
----------

- [Project home page](https://gitlab.gnome.org/swilmet/gnome-latex)
- [gnome-latex-extra](https://gitlab.gnome.org/swilmet/gnome-latex-extra) git
  repository
- [Tarballs](https://download.gnome.org/sources/gnome-latex/)
- [Old latexila tarballs](https://download.gnome.org/sources/latexila/)
- [Old mailing list](https://mail.gnome.org/mailman/listinfo/latexila-list)

Development and maintenance
---------------------------

The project is in low-maintenance state.
